@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use base qw{Net::GPSD3::Return::Unknown};
 
-our $VERSION='0.03';
+our $VERSION='0.12';
 
 =head1 NAME
 
@@ -43,7 +43,7 @@ GPSD's name for the device driver type. Won't be reported before gpsd has seen i
 
 =cut
 
-sub driver {shift->{"driver"}};
+sub driver {shift->{"driver"}||'none'};
 
 =head2 subtype
 
@@ -51,7 +51,7 @@ Whatever version information the device returned.
 
 =cut
 
-sub subtype {shift->{"subtype"}};
+sub subtype {shift->{"subtype"}||'none'};
 
 =head2 path
 
@@ -71,6 +71,8 @@ sub native {shift->{"native"}};
 
 Time the device was activated, or 0 if it is being closed.
 
+Note: I expect this to change to either a boolean or a timestamp in the 3.5 protocol.
+
 =cut
 
 sub activated {shift->{"activated"}};
@@ -129,24 +131,25 @@ Log on RT and Send to gpsd-dev email list
 
 =head1 SUPPORT
 
+DavisNetworks.com supports all Perl applications including this package.
+
 Try gpsd-dev email list
 
 =head1 AUTHOR
 
-    Michael R. Davis
-    CPAN ID: MRDVT
-    STOP, LLC
-    domain=>michaelrdavis,tld=>com,account=>perl
-    http://www.stopllc.com/
+  Michael R. Davis
+  CPAN ID: MRDVT
+  STOP, LLC
+  domain=>michaelrdavis,tld=>com,account=>perl
+  http://www.stopllc.com/
 
 =head1 COPYRIGHT
 
 This program is free software licensed under the...
 
-	The BSD License
+  The BSD License
 
-The full text of the license can be found in the
-LICENSE file included with this module.
+The full text of the license can be found in the LICENSE file included with this module.
 
 =head1 SEE ALSO
 
